.. OMoment documentation master file, created by
   sphinx-quickstart on Fri Oct 28 23:40:12 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

OMoment: Efficient online calculation of statistical moments
============================================================

.. automodule:: omoment
   :show-inheritance:

.. toctree::
   :maxdepth: 1
   :caption: API
   :glob:

   api/*

Index
=====

* :ref:`genindex`

